@@ -5,7 +5,7 @@ use strict;
 use DBI   1.57 ();
 use DynaLoader ();
 
-our $VERSION = '1.48';
+our $VERSION = '1.60';
 our @ISA     = 'DynaLoader';
 
 # sqlite_version cache (set in the XS bootstrap)
@@ -208,11 +208,12 @@ sub do {
     my ($dbh, $statement, $attr, @bind_values) = @_;
 
     # shortcut
+    my $allow_multiple_statements = $dbh->FETCH('sqlite_allow_multiple_statements');
     if  (defined $statement && !defined $attr && !@bind_values) {
         # _do() (i.e. sqlite3_exec()) runs semicolon-separate SQL
         # statements, which is handy but insecure sometimes.
         # Use this only when it's safe or explicitly allowed.
-        if (index($statement, ';') == -1 or $dbh->FETCH('sqlite_allow_multiple_statements')) {
+        if (index($statement, ';') == -1 or $allow_multiple_statements) {
             return DBD::SQLite::db::_do($dbh, $statement);
         }
     }
@@ -225,7 +226,7 @@ sub do {
         $sth->execute(splice @copy, 0, $sth->{NUM_OF_PARAMS}) or return undef;
         $rows += $sth->rows;
         # XXX: not sure why but $dbh->{sqlite...} wouldn't work here
-        last unless $dbh->FETCH('sqlite_allow_multiple_statements');
+        last unless $allow_multiple_statements;
         $statement = $sth->{sqlite_unprepared_statements};
     }
 
@@ -244,19 +245,11 @@ sub ping {
     return $dbh->FETCH('Active') ? 1 : 0;
 }
 
-sub _get_version {
-    return ( DBD::SQLite::db::FETCH($_[0], 'sqlite_version') );
-}
-
-my %info = (
-    17 => 'SQLite',       # SQL_DBMS_NAME
-    18 => \&_get_version, # SQL_DBMS_VER
-    29 => '"',            # SQL_IDENTIFIER_QUOTE_CHAR
-);
-
 sub get_info {
-    my($dbh, $info_type) = @_;
-    my $v = $info{int($info_type)};
+    my ($dbh, $info_type) = @_;
+
+    require DBD::SQLite::GetInfo;
+    my $v = $DBD::SQLite::GetInfo::info{int($info_type)};
     $v = $v->($dbh) if ref $v eq 'CODE';
     return $v;
 }
@@ -265,8 +258,8 @@ sub _attached_database_list {
     my $dbh = shift;
     my @attached;
 
-    my $sth_databases = $dbh->prepare( 'PRAGMA database_list' );
-    $sth_databases->execute;
+    my $sth_databases = $dbh->prepare( 'PRAGMA database_list' ) or return;
+    $sth_databases->execute or return;
     while ( my $db_info = $sth_databases->fetchrow_hashref ) {
         push @attached, $db_info->{name} if $db_info->{seq} >= 2;
     }
@@ -410,15 +403,15 @@ sub primary_key_info {
             ($dbname eq 'temp') ? 'sqlite_temp_master' :
             $quoted_dbname.'.sqlite_master';
 
-        my $sth = $dbh->prepare("SELECT name, sql FROM $master_table WHERE type = ?");
-        $sth->execute("table");
+        my $sth = $dbh->prepare("SELECT name, sql FROM $master_table WHERE type = ?") or return;
+        $sth->execute("table") or return;
         while(my $row = $sth->fetchrow_hashref) {
             my $tbname = $row->{name};
             next if defined $table && $table ne '%' && $table ne $tbname;
 
             my $quoted_tbname = $dbh->quote_identifier($tbname);
-            my $t_sth = $dbh->prepare("PRAGMA $quoted_dbname.table_info($quoted_tbname)");
-            $t_sth->execute;
+            my $t_sth = $dbh->prepare("PRAGMA $quoted_dbname.table_info($quoted_tbname)") or return;
+            $t_sth->execute or return;
             my @pk;
             while(my $col = $t_sth->fetchrow_hashref) {
                 push @pk, $col->{name} if $col->{pk};
@@ -552,10 +545,19 @@ my @FOREIGN_KEY_INFO_SQL_CLI = qw(
   UNIQUE_OR_PRIMARY
  );
 
+my $DEFERRABLE_RE = qr/
+    (?:(?:
+        on \s+ (?:delete|update) \s+ (?:set \s+ null|set \s+ default|cascade|restrict|no \s+ action)
+    |
+        match \s* (?:\S+|".+?(?<!")")
+    ) \s*)*
+    ((?:not)? \s* deferrable (?: \s* initially \s* (?: immediate | deferred))?)?
+/sxi;
+
 sub foreign_key_info {
     my ($dbh, $pk_catalog, $pk_schema, $pk_table, $fk_catalog, $fk_schema, $fk_table) = @_;
 
-    my $databases = $dbh->selectall_arrayref("PRAGMA database_list", {Slice => {}});
+    my $databases = $dbh->selectall_arrayref("PRAGMA database_list", {Slice => {}}) or return;
 
     my @fk_info;
     my %table_info;
@@ -569,14 +571,16 @@ sub foreign_key_info {
             ($dbname eq 'temp') ? 'sqlite_temp_master' :
             $quoted_dbname.'.sqlite_master';
 
-        my $tables = $dbh->selectall_arrayref("SELECT name FROM $master_table WHERE type = ?", undef, "table");
+        my $tables = $dbh->selectall_arrayref("SELECT name, sql FROM $master_table WHERE type = ?", undef, "table") or return;
         for my $table (@$tables) {
             my $tbname = $table->[0];
+            my $ddl = $table->[1];
+            my (@rels, %relid2rels);
             next if defined $fk_table && $fk_table ne '%' && $fk_table ne $tbname;
 
             my $quoted_tbname = $dbh->quote_identifier($tbname);
-            my $sth = $dbh->prepare("PRAGMA $quoted_dbname.foreign_key_list($quoted_tbname)");
-            $sth->execute;
+            my $sth = $dbh->prepare("PRAGMA $quoted_dbname.foreign_key_list($quoted_tbname)") or return;
+            $sth->execute or return;
             while(my $row = $sth->fetchrow_hashref) {
                 next if defined $pk_table && $pk_table ne '%' && $pk_table ne $row->{table};
 
@@ -584,8 +588,8 @@ sub foreign_key_info {
                     my $quoted_tb = $dbh->quote_identifier($row->{table});
                     for my $db (@$databases) {
                         my $quoted_db = $dbh->quote_identifier($db->{name});
-                        my $t_sth = $dbh->prepare("PRAGMA $quoted_db.table_info($quoted_tb)");
-                        $t_sth->execute;
+                        my $t_sth = $dbh->prepare("PRAGMA $quoted_db.table_info($quoted_tb)") or return;
+                        $t_sth->execute or return;
                         my $cols = {};
                         while(my $r = $t_sth->fetchrow_hashref) {
                             $cols->{$r->{name}} = $r->{pk};
@@ -602,7 +606,17 @@ sub foreign_key_info {
 
                 next if defined $pk_schema && $pk_schema ne '%' && $pk_schema ne $table_info{$row->{table}}{schema};
 
-                push @fk_info, {
+                # cribbed from DBIx::Class::Schema::Loader::DBI::SQLite
+                my $rel = $rels[ $row->{id} ] ||= {
+                    local_columns => [],
+                    remote_columns => undef,
+                    remote_table => $row->{table},
+                };
+                push @{ $rel->{local_columns} }, $row->{from};
+                push @{ $rel->{remote_columns} }, $row->{to}
+                    if defined $row->{to};
+
+                my $fk_row = {
                     PKTABLE_CAT   => undef,
                     PKTABLE_SCHEM => $table_info{$row->{table}}{schema},
                     PKTABLE_NAME  => $row->{table},
@@ -619,6 +633,44 @@ sub foreign_key_info {
                     DEFERRABILITY => undef,
                     UNIQUE_OR_PRIMARY => $table_info{$row->{table}}{columns}{$row->{to}} ? 'PRIMARY' : 'UNIQUE',
                 };
+                push @fk_info, $fk_row;
+                push @{ $relid2rels{$row->{id}} }, $fk_row; # keep so can fixup
+            }
+
+            # cribbed from DBIx::Class::Schema::Loader::DBI::SQLite
+            # but with additional parsing of which kind of deferrable
+            REL: for my $relid (keys %relid2rels) {
+                my $rel = $rels[$relid];
+                my $deferrable = $DBI_code_for_rule{'NOT DEFERRABLE'};
+                my $local_cols  = '"?' . (join '"? \s* , \s* "?', map quotemeta, @{ $rel->{local_columns} })        . '"?';
+                my $remote_cols = '"?' . (join '"? \s* , \s* "?', map quotemeta, @{ $rel->{remote_columns} || [] }) . '"?';
+                my ($deferrable_clause) = $ddl =~ /
+                        foreign \s+ key \s* \( \s* $local_cols \s* \) \s* references \s* (?:\S+|".+?(?<!")") \s*
+                        (?:\( \s* $remote_cols \s* \) \s*)?
+                        $DEFERRABLE_RE
+                /sxi;
+                if (!$deferrable_clause) {
+                    # check for inline constraint if 1 local column
+                    if (@{ $rel->{local_columns} } == 1) {
+                        my ($local_col)  = @{ $rel->{local_columns} };
+                        my ($remote_col) = @{ $rel->{remote_columns} || [] };
+                        $remote_col ||= '';
+                        ($deferrable_clause) = $ddl =~ /
+                            "?\Q$local_col\E"? \s* (?:\w+\s*)* (?: \( \s* \d\+ (?:\s*,\s*\d+)* \s* \) )? \s*
+                            references \s+ (?:\S+|".+?(?<!")") (?:\s* \( \s* "?\Q$remote_col\E"? \s* \))? \s*
+                            $DEFERRABLE_RE
+                        /sxi;
+                    }
+                }
+                if ($deferrable_clause) {
+                    # default is already NOT
+                    if ($deferrable_clause !~ /not/i) {
+                        $deferrable = $deferrable_clause =~ /deferred/i
+                            ? $DBI_code_for_rule{'INITIALLY DEFERRED'}
+                            : $DBI_code_for_rule{'INITIALLY IMMEDIATE'};
+                    }
+                }
+                $_->{DEFERRABILITY} = $deferrable for @{ $relid2rels{$relid} };
             }
         }
     }
@@ -655,7 +707,7 @@ my @STATISTICS_INFO_ODBC = (
 sub statistics_info {
     my ($dbh, $catalog, $schema, $table, $unique_only, $quick) = @_;
 
-    my $databases = $dbh->selectall_arrayref("PRAGMA database_list", {Slice => {}});
+    my $databases = $dbh->selectall_arrayref("PRAGMA database_list", {Slice => {}}) or return;
 
     my @statistics_info;
     for my $database (@$databases) {
@@ -668,22 +720,22 @@ sub statistics_info {
             ($dbname eq 'temp') ? 'sqlite_temp_master' :
             $quoted_dbname.'.sqlite_master';
 
-        my $tables = $dbh->selectall_arrayref("SELECT name FROM $master_table WHERE type = ?", undef, "table");
+        my $tables = $dbh->selectall_arrayref("SELECT name FROM $master_table WHERE type = ?", undef, "table") or return;
         for my $table_ref (@$tables) {
             my $tbname = $table_ref->[0];
-            next if defined $table && $table ne '%' && $table ne $tbname;
+            next if defined $table && $table ne '%' && uc($table) ne uc($tbname);
 
             my $quoted_tbname = $dbh->quote_identifier($tbname);
-            my $sth = $dbh->prepare("PRAGMA $quoted_dbname.index_list($quoted_tbname)");
-            $sth->execute;
+            my $sth = $dbh->prepare("PRAGMA $quoted_dbname.index_list($quoted_tbname)") or return;
+            $sth->execute or return;
             while(my $row = $sth->fetchrow_hashref) {
 
-                next if defined $unique_only && $unique_only && $row->{unique};
+                next if $unique_only && !$row->{unique};
                 my $quoted_idx = $dbh->quote_identifier($row->{name});
                 for my $db (@$databases) {
                     my $quoted_db = $dbh->quote_identifier($db->{name});
-                    my $i_sth = $dbh->prepare("PRAGMA $quoted_db.index_info($quoted_idx)");
-                    $i_sth->execute;
+                    my $i_sth = $dbh->prepare("PRAGMA $quoted_db.index_info($quoted_idx)") or return;
+                    $i_sth->execute or return;
                     my $cols = {};
                     while(my $info = $i_sth->fetchrow_hashref) {
                         push @statistics_info, {
@@ -834,8 +886,8 @@ END_SQL
     # Taken from Fey::Loader::SQLite
     my @cols;
     while ( my ($schema, $table) = $sth_tables->fetchrow_array ) {
-        my $sth_columns = $dbh->prepare(qq{PRAGMA "$schema".table_info("$table")});
-        $sth_columns->execute;
+        my $sth_columns = $dbh->prepare(qq{PRAGMA "$schema".table_info("$table")}) or return;
+        $sth_columns->execute or return;
 
         for ( my $position = 1; my $col_info = $sth_columns->fetchrow_hashref; $position++ ) {
             if ( defined $col_val ) {
@@ -854,7 +906,7 @@ END_SQL
             );
 
             my $type = $col_info->{type};
-            if ( $type =~ s/(\w+) ?\((\d+)(?:,(\d+))?\)/$1/ ) {
+            if ( $type =~ s/(\w+)\s*\(\s*(\d+)(?:\s*,\s*(\d+))?\s*\)/$1/ ) {
                 $col{COLUMN_SIZE}    = $2;
                 $col{DECIMAL_DIGITS} = $3;
             }
@@ -973,6 +1025,21 @@ on how to use DBI itself. The API works like every DBI module does.
 However, currently many statement attributes are not implemented or
 are limited by the typeless nature of the SQLite database.
 
+=head1 SQLITE VERSION
+
+DBD::SQLite is usually compiled with a bundled SQLite library
+(SQLite version S<3.25.2> as of this release) for consistency.
+However, a different version of SQLite may sometimes be used for
+some reasons like security, or some new experimental features.
+
+You can look at C<$DBD::SQLite::sqlite_version> (C<3.x.y> format) or
+C<$DBD::SQLite::sqlite_version_number> (C<3xxxyyy> format)
+to find which version of SQLite is actually used. You can also
+check C<DBD::SQLite::Constants::SQLITE_VERSION_NUMBER()>.
+
+You can also find how the library is compiled by calling
+C<DBD::SQLite::compile_options()> (see below).
+
 =head1 NOTABLE DIFFERENCES FROM OTHER DRIVERS
 
 =head2 Database Name Is A File Name
@@ -1010,18 +1077,26 @@ as well for finer control:
 
   my $dbh = DBI->connect("dbi:SQLite:uri=file:$path_to_dbfile?mode=rwc");
 
-Note that this is not for remote SQLite database connection. You only can
-connect to a local database.
+Note that this is not for remote SQLite database connection. You can
+only connect to a local database.
 
-You can also set sqlite_open_flags (only) when you connect to a database:
+=head2 Read-Only Database
 
-  use DBD::SQLite;
+You can set sqlite_open_flags (only) when you connect to a database:
+
+  use DBD::SQLite::Constants qw/:file_open/;
   my $dbh = DBI->connect("dbi:SQLite:$dbfile", undef, undef, {
-    sqlite_open_flags => DBD::SQLite::OPEN_READONLY,
+    sqlite_open_flags => SQLITE_OPEN_READONLY,
   });
 
 See L<http://www.sqlite.org/c3ref/open.html> for details.
 
+As of 1.49_05, you can also make a database read-only by setting
+C<ReadOnly> attribute to true (only) when you connect to a database.
+Actually you can set it after you connect, but in that case, it
+can't make the database read-only, and you'll see a warning (which
+you can hide by turning C<PrintWarn> off).
+
 =head2 DBD::SQLite And File::Temp
 
 When you use L<File::Temp> to create a temporary file/directory for
@@ -1158,6 +1233,15 @@ This is somewhat weird, but works anyway.
   });
   $sth->execute(5);
 
+=item Use SQL cast() function
+
+This is more explicit way to do the above.
+
+  my $sth = $dbh->prepare(q{
+    SELECT bar FROM foo GROUP BY bar HAVING count(*) > cast(? as integer);
+  });
+  $sth->execute(5);
+
 =item Set C<sqlite_see_if_its_a_number> database handle attribute
 
 As of version 1.32_02, you can use C<sqlite_see_if_its_a_number>
@@ -1217,39 +1301,6 @@ named) placeholders to avoid confusion.
   );
   $sth->execute(1, 2); 
 
-=head2 Foreign Keys
-
-B<BE PREPARED! WOLVES APPROACH!!>
-
-SQLite has started supporting foreign key constraints since 3.6.19
-(released on Oct 14, 2009; bundled in DBD::SQLite 1.26_05).
-To be exact, SQLite has long been able to parse a schema with foreign
-keys, but the constraints has not been enforced. Now you can issue
-a pragma actually to enable this feature and enforce the constraints.
-
-To do this, issue the following pragma (see below), preferably as
-soon as you connect to a database and you're not in a transaction:
-
-  $dbh->do("PRAGMA foreign_keys = ON");
-
-And you can explicitly disable the feature whenever you like by
-turning the pragma off:
-
-  $dbh->do("PRAGMA foreign_keys = OFF");
-
-As of this writing, this feature is disabled by default by the
-SQLite team, and by us, to secure backward compatibility, as
-this feature may break your applications, and actually broke
-some for us. If you have used a schema with foreign key constraints
-but haven't cared them much and supposed they're always ignored for
-SQLite, be prepared, and B<please do extensive testing to ensure
-that your applications will continue to work when the foreign keys
-support is enabled by default>. It is very likely that the SQLite
-team will turn it default-on in the future, and we plan to do it
-NO LATER THAN they do so.
-
-See L<http://www.sqlite.org/foreignkeys.html> for details.
-
 =head2 Pragma
 
 SQLite has a set of "Pragma"s to modify its operation or to query
@@ -1311,6 +1362,34 @@ in the worst case. See also L</"Performance"> section below.
 
 See L<http://www.sqlite.org/pragma.html> for more details.
 
+=head2 Foreign Keys
+
+SQLite has started supporting foreign key constraints since 3.6.19
+(released on Oct 14, 2009; bundled in DBD::SQLite 1.26_05).
+To be exact, SQLite has long been able to parse a schema with foreign
+keys, but the constraints has not been enforced. Now you can issue
+a C<foreign_keys> pragma to enable this feature and enforce the
+constraints, preferably as soon as you connect to a database and
+you're not in a transaction:
+
+  $dbh->do("PRAGMA foreign_keys = ON");
+
+And you can explicitly disable the feature whenever you like by
+turning the pragma off:
+
+  $dbh->do("PRAGMA foreign_keys = OFF");
+
+As of this writing, this feature is disabled by default by the
+SQLite team, and by us, to secure backward compatibility, as
+this feature may break your applications, and actually broke
+some for us. If you have used a schema with foreign key constraints
+but haven't cared them much and supposed they're always ignored for
+SQLite, be prepared, and please do extensive testing to ensure
+that your applications will continue to work when the foreign keys
+support is enabled by default.
+
+See L<http://www.sqlite.org/foreignkeys.html> for details.
+
 =head2 Transactions
 
 DBI/DBD::SQLite's transactions may be a bit confusing. They behave
@@ -1345,7 +1424,7 @@ a C<BEGIN> statement (only when an actual transaction has not
 begun yet) but you're not allowed to call C<begin_work> method
 (if you don't issue a C<BEGIN>, it will be issued internally).
 You can commit or roll it back freely. Another transaction will
-automatically begins if you execute another statement.
+automatically begin if you execute another statement.
 
   $dbh->{AutoCommit} = 0;
   
@@ -1425,15 +1504,24 @@ statements (a C<dump>) to a statement handle (via C<prepare> or C<do>),
 L<DBD::SQLite> only processes the first statement, and discards the
 rest.
 
-Since 1.30_01, you can retrieve those ignored (unprepared) statements
-via C<< $sth->{sqlite_unprepared_statements} >>. It usually contains
-nothing but white spaces, but if you really care, you can check this
-attribute to see if there's anything left undone. Also, if you set
+If you need to process multiple statements at a time, set 
 a C<sqlite_allow_multiple_statements> attribute of a database handle
-to true when you connect to a database, C<do> method automatically
-checks the C<sqlite_unprepared_statements> attribute, and if it finds
-anything undone (even if what's left is just a single white space),
-it repeats the process again, to the end.
+to true when you connect to a database, and C<do> method takes care
+of the rest (since 1.30_01, and without creating DBI's statement
+handles internally since 1.47_01). If you do need to use C<prepare>
+or C<prepare_cached> (which I don't recommend in this case, because
+typically there's no placeholder nor reusable part in a dump),
+you can look at << $sth->{sqlite_unprepared_statements} >> to retrieve
+what's left, though it usually contains nothing but white spaces.
+
+=head2 TYPE statement attribute
+
+Because of historical reasons, DBD::SQLite's C<TYPE> statement
+handle attribute returns an array ref of string values, contrary to
+the DBI specification. This value is also less useful for SQLite
+users because SQLite uses dynamic type system (that means,
+the datatype of a value is associated with the value itself, not
+with its container).
 
 =head2 Performance
 
@@ -1534,6 +1622,11 @@ If you set this to true, DBD::SQLite tries to see if the bind values
 are number or not, and does not quote if they are numbers. See above
 for details.
 
+=item sqlite_extended_result_codes
+
+If set to true, DBD::SQLite uses extended result codes where appropriate
+(see L<http://www.sqlite.org/rescode.html>).
+
 =back
 
 =head2 Statement Handle Attributes
@@ -1641,10 +1734,12 @@ B<DELETE_RULE>:
 The referential action for the DELETE rule.
 The codes are the same as for UPDATE_RULE.
 
-Unfortunately, the B<DEFERRABILITY> field is always C<undef>;
-as a matter of fact, deferrability clauses are supported by SQLite,
-but they can't be reported because the C<PRAGMA foreign_key_list>
-tells nothing about them.
+B<DEFERRABILITY>:
+The following codes are defined:
+
+  INITIALLY DEFERRED   5
+  INITIALLY IMMEDIATE  6
+  NOT DEFERRABLE       7
 
 B<UNIQUE_OR_PRIMARY>:
 Whether the column is primary or unique.
@@ -2151,6 +2246,28 @@ See also L<DBI::Profile> for better profiling options.
 
 is for internal use only.
 
+=head2 $dbh->sqlite_db_status()
+
+Returns a hash reference that holds a set of status information of database connection such as cache usage. See L<http://www.sqlite.org/c3ref/c_dbstatus_options.html> for details. You may also pass 0 as an argument to reset the status.
+
+=head2 $sth->sqlite_st_status()
+
+Returns a hash reference that holds a set of status information of SQLite statement handle such as full table scan count. See L<http://www.sqlite.org/c3ref/c_stmtstatus_counter.html> for details. Statement status only holds the current value.
+
+  my $status = $sth->sqlite_st_status();
+  my $cur = $status->{fullscan_step};
+
+You may also pass 0 as an argument to reset the status.
+
+=head2 $dbh->sqlite_create_module()
+
+Registers a name for a I<virtual table module>. Module names must be
+registered before creating a new virtual table using the module and
+before using a preexisting virtual table for the module.
+Virtual tables are explained in L<DBD::SQLite::VirtualTable>.
+
+=head1 DRIVER FUNCTIONS
+
 =head2 DBD::SQLite::compile_options()
 
 Returns an array of compile options (available since SQLite 3.6.23,
@@ -2167,25 +2284,13 @@ Returns a hash reference that holds a set of status information of SQLite runtim
 
 You may also pass 0 as an argument to reset the status.
 
-=head2 $dbh->sqlite_db_status()
+=head2 DBD::SQLite::strlike($pattern, $string, $escape_char), DBD::SQLite::strglob($pattern, $string)
 
-Returns a hash reference that holds a set of status information of database connection such as cache usage. See L<http://www.sqlite.org/c3ref/c_dbstatus_options.html> for details. You may also pass 0 as an argument to reset the status.
-
-=head2 $sth->sqlite_st_status()
-
-Returns a hash reference that holds a set of status information of SQLite statement handle such as full table scan count. See L<http://www.sqlite.org/c3ref/c_stmtstatus_counter.html> for details. Statement status only holds the current value.
-
-  my $status = $sth->sqlite_st_status();
-  my $cur = $status->{fullscan_step};
-
-You may also pass 0 as an argument to reset the status.
-
-=head2 $sth->sqlite_create_module()
-
-Registers a name for a I<virtual table module>. Module names must be
-registered before creating a new virtual table using the module and
-before using a preexisting virtual table for the module.
-Virtual tables are explained in L<DBD::SQLite::VirtualTable>.
+As of 1.49_05 (SQLite 3.10.0), you can use these two functions to
+see if a string matches a pattern. These may be useful when you
+create a virtual table or a custom function.
+See L<http://sqlite.org/c3ref/strlike.html> and
+L<http://sqlite.org/c3ref/strglob.html> for details.
 
 =head1 DRIVER CONSTANTS
 
@@ -2412,13 +2517,13 @@ then query which buildings overlap or are contained within a specified region:
 
   # IDs that are contained within query coordinates
   my $contained_sql = <<"";
-  SELECT id FROM try_rtree
+  SELECT id FROM city_buildings
      WHERE  minLong >= ? AND maxLong <= ?
      AND    minLat  >= ? AND maxLat  <= ?
   
   # ... and those that overlap query coordinates
   my $overlap_sql = <<"";
-  SELECT id FROM try_rtree
+  SELECT id FROM city_buildings
      WHERE    maxLong >= ? AND minLong <= ?
      AND      maxLat  >= ? AND minLat  <= ?
   
